YASL_isfloat

Function YASL_isfloat 

pub unsafe extern "C" fn YASL_isfloat(S: *mut YASL_State) -> bool
[-0, +0] checks if the top of the stack is float. @param S the YASL_State. @return true if the top of the stack is float, else false.